# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .app_password import *
from .cluster import *
from .cluster_replica import *
from .connection_aws_privatelink import *
from .connection_confluent_schema_registry import *
from .connection_kafka import *
from .connection_postgres import *
from .connection_ssh_tunnel import *
from .database import *
from .get_cluster_replicas import *
from .get_clusters import *
from .get_connections import *
from .get_current_cluster import *
from .get_current_database import *
from .get_databases import *
from .get_egress_ips import *
from .get_indexes import *
from .get_materialized_views import *
from .get_roles import *
from .get_schemas import *
from .get_scim_configs import *
from .get_scim_groups import *
from .get_secrets import *
from .get_sinks import *
from .get_sources import *
from .get_sso_config import *
from .get_tables import *
from .get_types import *
from .get_views import *
from .grant_cluster import *
from .grant_cluster_default_privilege import *
from .grant_connection import *
from .grant_connection_default_privilege import *
from .grant_database import *
from .grant_database_default_privilege import *
from .grant_materialized_view import *
from .grant_role import *
from .grant_schema import *
from .grant_schema_default_privilege import *
from .grant_secret import *
from .grant_secret_default_privilege import *
from .grant_source import *
from .grant_system_privilege import *
from .grant_table import *
from .grant_table_default_privilege import *
from .grant_type import *
from .grant_type_default_privilege import *
from .grant_view import *
from .index import *
from .materialized_view import *
from .provider import *
from .region import *
from .role import *
from .schema import *
from .scim2_configuration import *
from .secret import *
from .sink_kafka import *
from .source_kafka import *
from .source_loadgen import *
from .source_postgres import *
from .source_webhook import *
from .sso_config import *
from .sso_default_roles import *
from .sso_domain import *
from .sso_role_group_mapping import *
from .table import *
from .type import *
from .user import *
from .view import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_materialize.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_materialize.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "materialize",
  "mod": "index/appPassword",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/appPassword:AppPassword": "AppPassword"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/cluster",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/clusterReplica",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/clusterReplica:ClusterReplica": "ClusterReplica"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionAwsPrivatelink",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionAwsPrivatelink:ConnectionAwsPrivatelink": "ConnectionAwsPrivatelink"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionConfluentSchemaRegistry",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionConfluentSchemaRegistry:ConnectionConfluentSchemaRegistry": "ConnectionConfluentSchemaRegistry"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionKafka:ConnectionKafka": "ConnectionKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionPostgres",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionPostgres:ConnectionPostgres": "ConnectionPostgres"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionSshTunnel",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionSshTunnel:ConnectionSshTunnel": "ConnectionSshTunnel"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/database",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/database:Database": "Database"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantCluster",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantCluster:GrantCluster": "GrantCluster"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantClusterDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantClusterDefaultPrivilege:GrantClusterDefaultPrivilege": "GrantClusterDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantConnection",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantConnection:GrantConnection": "GrantConnection"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantConnectionDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantConnectionDefaultPrivilege:GrantConnectionDefaultPrivilege": "GrantConnectionDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantDatabase",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantDatabase:GrantDatabase": "GrantDatabase"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantDatabaseDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege": "GrantDatabaseDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantMaterializedView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantMaterializedView:GrantMaterializedView": "GrantMaterializedView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantRole",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantRole:GrantRole": "GrantRole"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSchema",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSchema:GrantSchema": "GrantSchema"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSchemaDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSchemaDefaultPrivilege:GrantSchemaDefaultPrivilege": "GrantSchemaDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSecret",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSecret:GrantSecret": "GrantSecret"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSecretDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSecretDefaultPrivilege:GrantSecretDefaultPrivilege": "GrantSecretDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSource",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSource:GrantSource": "GrantSource"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSystemPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSystemPrivilege:GrantSystemPrivilege": "GrantSystemPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTable",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTable:GrantTable": "GrantTable"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTableDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTableDefaultPrivilege:GrantTableDefaultPrivilege": "GrantTableDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantType",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantType:GrantType": "GrantType"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTypeDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTypeDefaultPrivilege:GrantTypeDefaultPrivilege": "GrantTypeDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantView:GrantView": "GrantView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/index",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/index:Index": "Index"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/materializedView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/materializedView:MaterializedView": "MaterializedView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/role",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/role:Role": "Role"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sCIM2Configuration",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sCIM2Configuration:SCIM2Configuration": "SCIM2Configuration"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSOConfig",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSOConfig:SSOConfig": "SSOConfig"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSODefaultRoles",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSODefaultRoles:SSODefaultRoles": "SSODefaultRoles"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSODomain",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSODomain:SSODomain": "SSODomain"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSORoleGroupMapping",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSORoleGroupMapping:SSORoleGroupMapping": "SSORoleGroupMapping"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/schema",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/secret",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sinkKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sinkKafka:SinkKafka": "SinkKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceKafka:SourceKafka": "SourceKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceLoadgen",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceLoadgen:SourceLoadgen": "SourceLoadgen"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourcePostgres",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourcePostgres:SourcePostgres": "SourcePostgres"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceWebhook",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceWebhook:SourceWebhook": "SourceWebhook"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/table",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/table:Table": "Table"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/type",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/type:Type": "Type"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/user",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/user:User": "User"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/view",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/view:View": "View"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "materialize",
  "token": "pulumi:providers:materialize",
  "fqn": "pulumi_materialize",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetCurrentClusterResult',
    'AwaitableGetCurrentClusterResult',
    'get_current_cluster',
]

@pulumi.output_type
class GetCurrentClusterResult:
    """
    A collection of values returned by GetCurrentCluster.
    """
    def __init__(__self__, id=None, name=None, region=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")


class AwaitableGetCurrentClusterResult(GetCurrentClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCurrentClusterResult(
            id=self.id,
            name=self.name,
            region=self.region)


def get_current_cluster(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCurrentClusterResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    current = materialize.get_current_cluster()
    pulumi.export("clusterName", current.name)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getCurrentCluster:GetCurrentCluster', __args__, opts=opts, typ=GetCurrentClusterResult).value

    return AwaitableGetCurrentClusterResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionKafkaArgs', 'ConnectionKafka']

@pulumi.input_type
class ConnectionKafkaArgs:
    def __init__(__self__, *,
                 kafka_brokers: pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]],
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 progress_topic: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 sasl_mechanisms: Optional[pulumi.Input[str]] = None,
                 sasl_password: Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']] = None,
                 sasl_username: Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 security_protocol: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']] = None,
                 ssl_certificate: Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']] = None,
                 ssl_certificate_authority: Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']] = None,
                 ssl_key: Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a ConnectionKafka resource.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]] kafka_brokers: The Kafka brokers configuration.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] progress_topic: The name of a topic that Kafka sinks can use to track internal consistency metadata.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] sasl_mechanisms: The SASL mechanism for the Kafka broker.
        :param pulumi.Input['ConnectionKafkaSaslPasswordArgs'] sasl_password: The SASL password for the Kafka broker.
        :param pulumi.Input['ConnectionKafkaSaslUsernameArgs'] sasl_username: The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema. Defaults to `public`.
        :param pulumi.Input[str] security_protocol: The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        :param pulumi.Input['ConnectionKafkaSshTunnelArgs'] ssh_tunnel: The default SSH tunnel configuration for the Kafka brokers.
        :param pulumi.Input['ConnectionKafkaSslCertificateArgs'] ssl_certificate: The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs'] ssl_certificate_authority: The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionKafkaSslKeyArgs'] ssl_key: The client key for the Kafka broker.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        pulumi.set(__self__, "kafka_brokers", kafka_brokers)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if progress_topic is not None:
            pulumi.set(__self__, "progress_topic", progress_topic)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sasl_mechanisms is not None:
            pulumi.set(__self__, "sasl_mechanisms", sasl_mechanisms)
        if sasl_password is not None:
            pulumi.set(__self__, "sasl_password", sasl_password)
        if sasl_username is not None:
            pulumi.set(__self__, "sasl_username", sasl_username)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if security_protocol is not None:
            pulumi.set(__self__, "security_protocol", security_protocol)
        if ssh_tunnel is not None:
            pulumi.set(__self__, "ssh_tunnel", ssh_tunnel)
        if ssl_certificate is not None:
            pulumi.set(__self__, "ssl_certificate", ssl_certificate)
        if ssl_certificate_authority is not None:
            pulumi.set(__self__, "ssl_certificate_authority", ssl_certificate_authority)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter(name="kafkaBrokers")
    def kafka_brokers(self) -> pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]]:
        """
        The Kafka brokers configuration.
        """
        return pulumi.get(self, "kafka_brokers")

    @kafka_brokers.setter
    def kafka_brokers(self, value: pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]]):
        pulumi.set(self, "kafka_brokers", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="progressTopic")
    def progress_topic(self) -> Optional[pulumi.Input[str]]:
        """
        The name of a topic that Kafka sinks can use to track internal consistency metadata.
        """
        return pulumi.get(self, "progress_topic")

    @progress_topic.setter
    def progress_topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "progress_topic", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="saslMechanisms")
    def sasl_mechanisms(self) -> Optional[pulumi.Input[str]]:
        """
        The SASL mechanism for the Kafka broker.
        """
        return pulumi.get(self, "sasl_mechanisms")

    @sasl_mechanisms.setter
    def sasl_mechanisms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sasl_mechanisms", value)

    @property
    @pulumi.getter(name="saslPassword")
    def sasl_password(self) -> Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']]:
        """
        The SASL password for the Kafka broker.
        """
        return pulumi.get(self, "sasl_password")

    @sasl_password.setter
    def sasl_password(self, value: Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']]):
        pulumi.set(self, "sasl_password", value)

    @property
    @pulumi.getter(name="saslUsername")
    def sasl_username(self) -> Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']]:
        """
        The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "sasl_username")

    @sasl_username.setter
    def sasl_username(self, value: Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']]):
        pulumi.set(self, "sasl_username", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="securityProtocol")
    def security_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        """
        return pulumi.get(self, "security_protocol")

    @security_protocol.setter
    def security_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_protocol", value)

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']]:
        """
        The default SSH tunnel configuration for the Kafka brokers.
        """
        return pulumi.get(self, "ssh_tunnel")

    @ssh_tunnel.setter
    def ssh_tunnel(self, value: Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']]):
        pulumi.set(self, "ssh_tunnel", value)

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']]:
        """
        The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @ssl_certificate.setter
    def ssl_certificate(self, value: Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']]):
        pulumi.set(self, "ssl_certificate", value)

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']]:
        """
        The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @ssl_certificate_authority.setter
    def ssl_certificate_authority(self, value: Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']]):
        pulumi.set(self, "ssl_certificate_authority", value)

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']]:
        """
        The client key for the Kafka broker.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']]):
        pulumi.set(self, "ssl_key", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


@pulumi.input_type
class _ConnectionKafkaState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 kafka_brokers: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 progress_topic: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 sasl_mechanisms: Optional[pulumi.Input[str]] = None,
                 sasl_password: Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']] = None,
                 sasl_username: Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 security_protocol: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']] = None,
                 ssl_certificate: Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']] = None,
                 ssl_certificate_authority: Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']] = None,
                 ssl_key: Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering ConnectionKafka resources.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]] kafka_brokers: The Kafka brokers configuration.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] progress_topic: The name of a topic that Kafka sinks can use to track internal consistency metadata.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] sasl_mechanisms: The SASL mechanism for the Kafka broker.
        :param pulumi.Input['ConnectionKafkaSaslPasswordArgs'] sasl_password: The SASL password for the Kafka broker.
        :param pulumi.Input['ConnectionKafkaSaslUsernameArgs'] sasl_username: The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema. Defaults to `public`.
        :param pulumi.Input[str] security_protocol: The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        :param pulumi.Input['ConnectionKafkaSshTunnelArgs'] ssh_tunnel: The default SSH tunnel configuration for the Kafka brokers.
        :param pulumi.Input['ConnectionKafkaSslCertificateArgs'] ssl_certificate: The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs'] ssl_certificate_authority: The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionKafkaSslKeyArgs'] ssl_key: The client key for the Kafka broker.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if kafka_brokers is not None:
            pulumi.set(__self__, "kafka_brokers", kafka_brokers)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if progress_topic is not None:
            pulumi.set(__self__, "progress_topic", progress_topic)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sasl_mechanisms is not None:
            pulumi.set(__self__, "sasl_mechanisms", sasl_mechanisms)
        if sasl_password is not None:
            pulumi.set(__self__, "sasl_password", sasl_password)
        if sasl_username is not None:
            pulumi.set(__self__, "sasl_username", sasl_username)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if security_protocol is not None:
            pulumi.set(__self__, "security_protocol", security_protocol)
        if ssh_tunnel is not None:
            pulumi.set(__self__, "ssh_tunnel", ssh_tunnel)
        if ssl_certificate is not None:
            pulumi.set(__self__, "ssl_certificate", ssl_certificate)
        if ssl_certificate_authority is not None:
            pulumi.set(__self__, "ssl_certificate_authority", ssl_certificate_authority)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="kafkaBrokers")
    def kafka_brokers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]]]:
        """
        The Kafka brokers configuration.
        """
        return pulumi.get(self, "kafka_brokers")

    @kafka_brokers.setter
    def kafka_brokers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionKafkaKafkaBrokerArgs']]]]):
        pulumi.set(self, "kafka_brokers", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="progressTopic")
    def progress_topic(self) -> Optional[pulumi.Input[str]]:
        """
        The name of a topic that Kafka sinks can use to track internal consistency metadata.
        """
        return pulumi.get(self, "progress_topic")

    @progress_topic.setter
    def progress_topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "progress_topic", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="saslMechanisms")
    def sasl_mechanisms(self) -> Optional[pulumi.Input[str]]:
        """
        The SASL mechanism for the Kafka broker.
        """
        return pulumi.get(self, "sasl_mechanisms")

    @sasl_mechanisms.setter
    def sasl_mechanisms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sasl_mechanisms", value)

    @property
    @pulumi.getter(name="saslPassword")
    def sasl_password(self) -> Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']]:
        """
        The SASL password for the Kafka broker.
        """
        return pulumi.get(self, "sasl_password")

    @sasl_password.setter
    def sasl_password(self, value: Optional[pulumi.Input['ConnectionKafkaSaslPasswordArgs']]):
        pulumi.set(self, "sasl_password", value)

    @property
    @pulumi.getter(name="saslUsername")
    def sasl_username(self) -> Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']]:
        """
        The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "sasl_username")

    @sasl_username.setter
    def sasl_username(self, value: Optional[pulumi.Input['ConnectionKafkaSaslUsernameArgs']]):
        pulumi.set(self, "sasl_username", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="securityProtocol")
    def security_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        """
        return pulumi.get(self, "security_protocol")

    @security_protocol.setter
    def security_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_protocol", value)

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']]:
        """
        The default SSH tunnel configuration for the Kafka brokers.
        """
        return pulumi.get(self, "ssh_tunnel")

    @ssh_tunnel.setter
    def ssh_tunnel(self, value: Optional[pulumi.Input['ConnectionKafkaSshTunnelArgs']]):
        pulumi.set(self, "ssh_tunnel", value)

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']]:
        """
        The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @ssl_certificate.setter
    def ssl_certificate(self, value: Optional[pulumi.Input['ConnectionKafkaSslCertificateArgs']]):
        pulumi.set(self, "ssl_certificate", value)

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']]:
        """
        The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @ssl_certificate_authority.setter
    def ssl_certificate_authority(self, value: Optional[pulumi.Input['ConnectionKafkaSslCertificateAuthorityArgs']]):
        pulumi.set(self, "ssl_certificate_authority", value)

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']]:
        """
        The client key for the Kafka broker.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input['ConnectionKafkaSslKeyArgs']]):
        pulumi.set(self, "ssl_key", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


class ConnectionKafka(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 kafka_brokers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ConnectionKafkaKafkaBrokerArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 progress_topic: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 sasl_mechanisms: Optional[pulumi.Input[str]] = None,
                 sasl_password: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslPasswordArgs']]] = None,
                 sasl_username: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslUsernameArgs']]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 security_protocol: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSshTunnelArgs']]] = None,
                 ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateArgs']]] = None,
                 ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateAuthorityArgs']]] = None,
                 ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslKeyArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        A Kafka connection establishes a link to a Kafka cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a Kafka Connection
        example_kafka_connection = materialize.ConnectionKafka("exampleKafkaConnection",
            kafka_brokers=[materialize.ConnectionKafkaKafkaBrokerArgs(
                broker="b-1.hostname-1:9096",
            )],
            progress_topic="example",
            sasl_mechanisms="SCRAM-SHA-256",
            sasl_password=materialize.ConnectionKafkaSaslPasswordArgs(
                database_name="materialize",
                name="kafka_password",
                schema_name="public",
            ),
            sasl_username=materialize.ConnectionKafkaSaslUsernameArgs(
                text="user",
            ))
        example_kafka_connection_multiple_brokers = materialize.ConnectionKafka("exampleKafkaConnectionMultipleBrokers", kafka_brokers=[
            materialize.ConnectionKafkaKafkaBrokerArgs(
                availability_zone="use1-az1",
                broker="b-1.hostname-1:9096",
                privatelink_connection=materialize.ConnectionKafkaKafkaBrokerPrivatelinkConnectionArgs(
                    database_name="materialize",
                    name="example_aws_privatelink_conn",
                    schema_name="public",
                ),
                target_group_port=9001,
            ),
            materialize.ConnectionKafkaKafkaBrokerArgs(
                availability_zone="use1-az2",
                broker="b-2.hostname-2:9096",
                privatelink_connection=materialize.ConnectionKafkaKafkaBrokerPrivatelinkConnectionArgs(
                    database_name="materialize",
                    name="example_aws_privatelink_conn",
                    schema_name="public",
                ),
                target_group_port=9002,
            ),
        ])
        ```

        ## Import

        Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionKafka:ConnectionKafka example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ConnectionKafkaKafkaBrokerArgs']]]] kafka_brokers: The Kafka brokers configuration.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] progress_topic: The name of a topic that Kafka sinks can use to track internal consistency metadata.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] sasl_mechanisms: The SASL mechanism for the Kafka broker.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSaslPasswordArgs']] sasl_password: The SASL password for the Kafka broker.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSaslUsernameArgs']] sasl_username: The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema. Defaults to `public`.
        :param pulumi.Input[str] security_protocol: The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSshTunnelArgs']] ssh_tunnel: The default SSH tunnel configuration for the Kafka brokers.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateArgs']] ssl_certificate: The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateAuthorityArgs']] ssl_certificate_authority: The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslKeyArgs']] ssl_key: The client key for the Kafka broker.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionKafkaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Kafka connection establishes a link to a Kafka cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a Kafka Connection
        example_kafka_connection = materialize.ConnectionKafka("exampleKafkaConnection",
            kafka_brokers=[materialize.ConnectionKafkaKafkaBrokerArgs(
                broker="b-1.hostname-1:9096",
            )],
            progress_topic="example",
            sasl_mechanisms="SCRAM-SHA-256",
            sasl_password=materialize.ConnectionKafkaSaslPasswordArgs(
                database_name="materialize",
                name="kafka_password",
                schema_name="public",
            ),
            sasl_username=materialize.ConnectionKafkaSaslUsernameArgs(
                text="user",
            ))
        example_kafka_connection_multiple_brokers = materialize.ConnectionKafka("exampleKafkaConnectionMultipleBrokers", kafka_brokers=[
            materialize.ConnectionKafkaKafkaBrokerArgs(
                availability_zone="use1-az1",
                broker="b-1.hostname-1:9096",
                privatelink_connection=materialize.ConnectionKafkaKafkaBrokerPrivatelinkConnectionArgs(
                    database_name="materialize",
                    name="example_aws_privatelink_conn",
                    schema_name="public",
                ),
                target_group_port=9001,
            ),
            materialize.ConnectionKafkaKafkaBrokerArgs(
                availability_zone="use1-az2",
                broker="b-2.hostname-2:9096",
                privatelink_connection=materialize.ConnectionKafkaKafkaBrokerPrivatelinkConnectionArgs(
                    database_name="materialize",
                    name="example_aws_privatelink_conn",
                    schema_name="public",
                ),
                target_group_port=9002,
            ),
        ])
        ```

        ## Import

        Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionKafka:ConnectionKafka example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ConnectionKafkaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionKafkaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 kafka_brokers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ConnectionKafkaKafkaBrokerArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 progress_topic: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 sasl_mechanisms: Optional[pulumi.Input[str]] = None,
                 sasl_password: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslPasswordArgs']]] = None,
                 sasl_username: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslUsernameArgs']]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 security_protocol: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSshTunnelArgs']]] = None,
                 ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateArgs']]] = None,
                 ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateAuthorityArgs']]] = None,
                 ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslKeyArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionKafkaArgs.__new__(ConnectionKafkaArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            if kafka_brokers is None and not opts.urn:
                raise TypeError("Missing required property 'kafka_brokers'")
            __props__.__dict__["kafka_brokers"] = kafka_brokers
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["progress_topic"] = progress_topic
            __props__.__dict__["region"] = region
            __props__.__dict__["sasl_mechanisms"] = sasl_mechanisms
            __props__.__dict__["sasl_password"] = sasl_password
            __props__.__dict__["sasl_username"] = sasl_username
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["security_protocol"] = security_protocol
            __props__.__dict__["ssh_tunnel"] = ssh_tunnel
            __props__.__dict__["ssl_certificate"] = ssl_certificate
            __props__.__dict__["ssl_certificate_authority"] = ssl_certificate_authority
            __props__.__dict__["ssl_key"] = ssl_key
            __props__.__dict__["validate"] = validate
            __props__.__dict__["qualified_sql_name"] = None
        super(ConnectionKafka, __self__).__init__(
            'materialize:index/connectionKafka:ConnectionKafka',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            kafka_brokers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ConnectionKafkaKafkaBrokerArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            progress_topic: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            sasl_mechanisms: Optional[pulumi.Input[str]] = None,
            sasl_password: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslPasswordArgs']]] = None,
            sasl_username: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSaslUsernameArgs']]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            security_protocol: Optional[pulumi.Input[str]] = None,
            ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSshTunnelArgs']]] = None,
            ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateArgs']]] = None,
            ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateAuthorityArgs']]] = None,
            ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionKafkaSslKeyArgs']]] = None,
            validate: Optional[pulumi.Input[bool]] = None) -> 'ConnectionKafka':
        """
        Get an existing ConnectionKafka resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ConnectionKafkaKafkaBrokerArgs']]]] kafka_brokers: The Kafka brokers configuration.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] progress_topic: The name of a topic that Kafka sinks can use to track internal consistency metadata.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] sasl_mechanisms: The SASL mechanism for the Kafka broker.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSaslPasswordArgs']] sasl_password: The SASL password for the Kafka broker.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSaslUsernameArgs']] sasl_username: The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema. Defaults to `public`.
        :param pulumi.Input[str] security_protocol: The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSshTunnelArgs']] ssh_tunnel: The default SSH tunnel configuration for the Kafka brokers.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateArgs']] ssl_certificate: The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslCertificateAuthorityArgs']] ssl_certificate_authority: The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionKafkaSslKeyArgs']] ssl_key: The client key for the Kafka broker.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionKafkaState.__new__(_ConnectionKafkaState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["kafka_brokers"] = kafka_brokers
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["progress_topic"] = progress_topic
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["sasl_mechanisms"] = sasl_mechanisms
        __props__.__dict__["sasl_password"] = sasl_password
        __props__.__dict__["sasl_username"] = sasl_username
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["security_protocol"] = security_protocol
        __props__.__dict__["ssh_tunnel"] = ssh_tunnel
        __props__.__dict__["ssl_certificate"] = ssl_certificate
        __props__.__dict__["ssl_certificate_authority"] = ssl_certificate_authority
        __props__.__dict__["ssl_key"] = ssl_key
        __props__.__dict__["validate"] = validate
        return ConnectionKafka(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="kafkaBrokers")
    def kafka_brokers(self) -> pulumi.Output[Sequence['outputs.ConnectionKafkaKafkaBroker']]:
        """
        The Kafka brokers configuration.
        """
        return pulumi.get(self, "kafka_brokers")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="progressTopic")
    def progress_topic(self) -> pulumi.Output[Optional[str]]:
        """
        The name of a topic that Kafka sinks can use to track internal consistency metadata.
        """
        return pulumi.get(self, "progress_topic")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="saslMechanisms")
    def sasl_mechanisms(self) -> pulumi.Output[Optional[str]]:
        """
        The SASL mechanism for the Kafka broker.
        """
        return pulumi.get(self, "sasl_mechanisms")

    @property
    @pulumi.getter(name="saslPassword")
    def sasl_password(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSaslPassword']]:
        """
        The SASL password for the Kafka broker.
        """
        return pulumi.get(self, "sasl_password")

    @property
    @pulumi.getter(name="saslUsername")
    def sasl_username(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSaslUsername']]:
        """
        The SASL username for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "sasl_username")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="securityProtocol")
    def security_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        The security protocol to use: `PLAINTEXT`, `SSL`, `SASL_PLAINTEXT`, or `SASL_SSL`.
        """
        return pulumi.get(self, "security_protocol")

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSshTunnel']]:
        """
        The default SSH tunnel configuration for the Kafka brokers.
        """
        return pulumi.get(self, "ssh_tunnel")

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSslCertificate']]:
        """
        The client certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSslCertificateAuthority']]:
        """
        The CA certificate for the Kafka broker.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> pulumi.Output[Optional['outputs.ConnectionKafkaSslKey']]:
        """
        The client key for the Kafka broker.
        """
        return pulumi.get(self, "ssl_key")

    @property
    @pulumi.getter
    def validate(self) -> pulumi.Output[Optional[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['MaterializedViewArgs', 'MaterializedView']

@pulumi.input_type
class MaterializedViewArgs:
    def __init__(__self__, *,
                 cluster_name: pulumi.Input[str],
                 statement: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_null_assertions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MaterializedView resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain the materialized view.
        :param pulumi.Input[str] statement: The SQL statement for the materialized view.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the materialized view.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] not_null_assertions: **Private Preview** A list of columns for which to create non-null assertions.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the materialized view schema. Defaults to `public`.
        """
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "statement", statement)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if not_null_assertions is not None:
            pulumi.set(__self__, "not_null_assertions", not_null_assertions)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[str]:
        """
        The cluster to maintain the materialized view.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def statement(self) -> pulumi.Input[str]:
        """
        The SQL statement for the materialized view.
        """
        return pulumi.get(self, "statement")

    @statement.setter
    def statement(self, value: pulumi.Input[str]):
        pulumi.set(self, "statement", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notNullAssertions")
    def not_null_assertions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        **Private Preview** A list of columns for which to create non-null assertions.
        """
        return pulumi.get(self, "not_null_assertions")

    @not_null_assertions.setter
    def not_null_assertions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "not_null_assertions", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)


@pulumi.input_type
class _MaterializedViewState:
    def __init__(__self__, *,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 create_sql: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_null_assertions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 statement: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MaterializedView resources.
        :param pulumi.Input[str] cluster_name: The cluster to maintain the materialized view.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] create_sql: The SQL statement used to create the materialized view.
        :param pulumi.Input[str] database_name: The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the materialized view.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] not_null_assertions: **Private Preview** A list of columns for which to create non-null assertions.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the materialized view.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the materialized view schema. Defaults to `public`.
        :param pulumi.Input[str] statement: The SQL statement for the materialized view.
        """
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if create_sql is not None:
            pulumi.set(__self__, "create_sql", create_sql)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if not_null_assertions is not None:
            pulumi.set(__self__, "not_null_assertions", not_null_assertions)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if statement is not None:
            pulumi.set(__self__, "statement", statement)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain the materialized view.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="createSql")
    def create_sql(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL statement used to create the materialized view.
        """
        return pulumi.get(self, "create_sql")

    @create_sql.setter
    def create_sql(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_sql", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notNullAssertions")
    def not_null_assertions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        **Private Preview** A list of columns for which to create non-null assertions.
        """
        return pulumi.get(self, "not_null_assertions")

    @not_null_assertions.setter
    def not_null_assertions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "not_null_assertions", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the materialized view.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the materialized view schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def statement(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL statement for the materialized view.
        """
        return pulumi.get(self, "statement")

    @statement.setter
    def statement(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "statement", value)


class MaterializedView(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_null_assertions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 statement: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Materialized views represent query results stored durably.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        simple_materialized_view_materialized_view = materialize.MaterializedView("simpleMaterializedViewMaterializedView",
            schema_name=materialize_schema["schema"]["name"],
            database_name=materialize_database["database"]["name"],
            statement=f\"\"\"SELECT
            *
        FROM
            {materialize_table["simple_table"]["qualified_name"]}
        \"\"\",
            opts=pulumi.ResourceOptions(depends_on=[materialize_table["simple_table"]]))
        simple_materialized_view_index_materialized_view_materialized_view = materialize.MaterializedView("simpleMaterializedViewIndex/materializedViewMaterializedView",
            schema_name=materialize_schema["schema"]["name"],
            database_name=materialize_database["database"]["name"],
            statement="SELECT * FROM materialize.public.simple_table")
        ```

        ## Import

        Materialized views can be imported using the materialized view id

        ```sh
         $ pulumi import materialize:index/materializedView:MaterializedView example_materialize_view <region>:<view_id>
        ```

         Materialized view id and information be found in the `mz_catalog.mz_materialized_views` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain the materialized view.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the materialized view.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] not_null_assertions: **Private Preview** A list of columns for which to create non-null assertions.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the materialized view schema. Defaults to `public`.
        :param pulumi.Input[str] statement: The SQL statement for the materialized view.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MaterializedViewArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Materialized views represent query results stored durably.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        simple_materialized_view_materialized_view = materialize.MaterializedView("simpleMaterializedViewMaterializedView",
            schema_name=materialize_schema["schema"]["name"],
            database_name=materialize_database["database"]["name"],
            statement=f\"\"\"SELECT
            *
        FROM
            {materialize_table["simple_table"]["qualified_name"]}
        \"\"\",
            opts=pulumi.ResourceOptions(depends_on=[materialize_table["simple_table"]]))
        simple_materialized_view_index_materialized_view_materialized_view = materialize.MaterializedView("simpleMaterializedViewIndex/materializedViewMaterializedView",
            schema_name=materialize_schema["schema"]["name"],
            database_name=materialize_database["database"]["name"],
            statement="SELECT * FROM materialize.public.simple_table")
        ```

        ## Import

        Materialized views can be imported using the materialized view id

        ```sh
         $ pulumi import materialize:index/materializedView:MaterializedView example_materialize_view <region>:<view_id>
        ```

         Materialized view id and information be found in the `mz_catalog.mz_materialized_views` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param MaterializedViewArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MaterializedViewArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_null_assertions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 statement: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MaterializedViewArgs.__new__(MaterializedViewArgs)

            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["name"] = name
            __props__.__dict__["not_null_assertions"] = not_null_assertions
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            if statement is None and not opts.urn:
                raise TypeError("Missing required property 'statement'")
            __props__.__dict__["statement"] = statement
            __props__.__dict__["create_sql"] = None
            __props__.__dict__["qualified_sql_name"] = None
        super(MaterializedView, __self__).__init__(
            'materialize:index/materializedView:MaterializedView',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            create_sql: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            not_null_assertions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            statement: Optional[pulumi.Input[str]] = None) -> 'MaterializedView':
        """
        Get an existing MaterializedView resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain the materialized view.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] create_sql: The SQL statement used to create the materialized view.
        :param pulumi.Input[str] database_name: The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the materialized view.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] not_null_assertions: **Private Preview** A list of columns for which to create non-null assertions.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the materialized view.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the materialized view schema. Defaults to `public`.
        :param pulumi.Input[str] statement: The SQL statement for the materialized view.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MaterializedViewState.__new__(_MaterializedViewState)

        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["create_sql"] = create_sql
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["name"] = name
        __props__.__dict__["not_null_assertions"] = not_null_assertions
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["statement"] = statement
        return MaterializedView(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain the materialized view.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="createSql")
    def create_sql(self) -> pulumi.Output[str]:
        """
        The SQL statement used to create the materialized view.
        """
        return pulumi.get(self, "create_sql")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the materialized view database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the materialized view.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="notNullAssertions")
    def not_null_assertions(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        **Private Preview** A list of columns for which to create non-null assertions.
        """
        return pulumi.get(self, "not_null_assertions")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the materialized view.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the materialized view schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def statement(self) -> pulumi.Output[str]:
        """
        The SQL statement for the materialized view.
        """
        return pulumi.get(self, "statement")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetEgressIpsResult',
    'AwaitableGetEgressIpsResult',
    'get_egress_ips',
]

@pulumi.output_type
class GetEgressIpsResult:
    """
    A collection of values returned by GetEgressIps.
    """
    def __init__(__self__, egress_ips=None, id=None, region=None):
        if egress_ips and not isinstance(egress_ips, list):
            raise TypeError("Expected argument 'egress_ips' to be a list")
        pulumi.set(__self__, "egress_ips", egress_ips)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="egressIps")
    def egress_ips(self) -> Sequence[str]:
        """
        The egress IPs in the account
        """
        return pulumi.get(self, "egress_ips")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")


class AwaitableGetEgressIpsResult(GetEgressIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEgressIpsResult(
            egress_ips=self.egress_ips,
            id=self.id,
            region=self.region)


def get_egress_ips(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEgressIpsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_egress_ips()
    pulumi.export("ips", all.egress_ips)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getEgressIps:GetEgressIps', __args__, opts=opts, typ=GetEgressIpsResult).value

    return AwaitableGetEgressIpsResult(
        egress_ips=pulumi.get(__ret__, 'egress_ips'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 disk: Optional[pulumi.Input[bool]] = None,
                 idle_arrangement_merge_effort: Optional[pulumi.Input[int]] = None,
                 introspection_debugging: Optional[pulumi.Input[bool]] = None,
                 introspection_interval: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 replication_factor: Optional[pulumi.Input[int]] = None,
                 size: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] disk: **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        :param pulumi.Input[int] idle_arrangement_merge_effort: The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        :param pulumi.Input[bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[str] name: The identifier for the cluster.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[str] size: The size of the managed cluster.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if idle_arrangement_merge_effort is not None:
            pulumi.set(__self__, "idle_arrangement_merge_effort", idle_arrangement_merge_effort)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def disk(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disk", value)

    @property
    @pulumi.getter(name="idleArrangementMergeEffort")
    def idle_arrangement_merge_effort(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        """
        return pulumi.get(self, "idle_arrangement_merge_effort")

    @idle_arrangement_merge_effort.setter
    def idle_arrangement_merge_effort(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "idle_arrangement_merge_effort", value)

    @property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "introspection_interval", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[int]]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "replication_factor", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 disk: Optional[pulumi.Input[bool]] = None,
                 idle_arrangement_merge_effort: Optional[pulumi.Input[int]] = None,
                 introspection_debugging: Optional[pulumi.Input[bool]] = None,
                 introspection_interval: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 replication_factor: Optional[pulumi.Input[int]] = None,
                 size: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] disk: **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        :param pulumi.Input[int] idle_arrangement_merge_effort: The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        :param pulumi.Input[bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[str] name: The identifier for the cluster.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[str] size: The size of the managed cluster.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if idle_arrangement_merge_effort is not None:
            pulumi.set(__self__, "idle_arrangement_merge_effort", idle_arrangement_merge_effort)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def disk(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disk", value)

    @property
    @pulumi.getter(name="idleArrangementMergeEffort")
    def idle_arrangement_merge_effort(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        """
        return pulumi.get(self, "idle_arrangement_merge_effort")

    @idle_arrangement_merge_effort.setter
    def idle_arrangement_merge_effort(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "idle_arrangement_merge_effort", value)

    @property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "introspection_interval", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[int]]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "replication_factor", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)


class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 disk: Optional[pulumi.Input[bool]] = None,
                 idle_arrangement_merge_effort: Optional[pulumi.Input[int]] = None,
                 introspection_debugging: Optional[pulumi.Input[bool]] = None,
                 introspection_interval: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 replication_factor: Optional[pulumi.Input[int]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Clusters describe logical compute resources that can be used by sources, sinks, indexes, and materialized views. Managed clusters are created by setting the `size` attribute

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster = materialize.Cluster("exampleCluster")
        ```

        ## Import

        Clusters can be imported using the cluster id

        ```sh
         $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:<cluster_id>
        ```

         Cluster id and information be found in the `mz_catalog.mz_clusters` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] disk: **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        :param pulumi.Input[int] idle_arrangement_merge_effort: The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        :param pulumi.Input[bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[str] name: The identifier for the cluster.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[str] size: The size of the managed cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ClusterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Clusters describe logical compute resources that can be used by sources, sinks, indexes, and materialized views. Managed clusters are created by setting the `size` attribute

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster = materialize.Cluster("exampleCluster")
        ```

        ## Import

        Clusters can be imported using the cluster id

        ```sh
         $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:<cluster_id>
        ```

         Cluster id and information be found in the `mz_catalog.mz_clusters` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 disk: Optional[pulumi.Input[bool]] = None,
                 idle_arrangement_merge_effort: Optional[pulumi.Input[int]] = None,
                 introspection_debugging: Optional[pulumi.Input[bool]] = None,
                 introspection_interval: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 replication_factor: Optional[pulumi.Input[int]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["disk"] = disk
            __props__.__dict__["idle_arrangement_merge_effort"] = idle_arrangement_merge_effort
            __props__.__dict__["introspection_debugging"] = introspection_debugging
            __props__.__dict__["introspection_interval"] = introspection_interval
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["replication_factor"] = replication_factor
            __props__.__dict__["size"] = size
        super(Cluster, __self__).__init__(
            'materialize:index/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            disk: Optional[pulumi.Input[bool]] = None,
            idle_arrangement_merge_effort: Optional[pulumi.Input[int]] = None,
            introspection_debugging: Optional[pulumi.Input[bool]] = None,
            introspection_interval: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            replication_factor: Optional[pulumi.Input[int]] = None,
            size: Optional[pulumi.Input[str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] disk: **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        :param pulumi.Input[int] idle_arrangement_merge_effort: The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        :param pulumi.Input[bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[str] name: The identifier for the cluster.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[str] size: The size of the managed cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["disk"] = disk
        __props__.__dict__["idle_arrangement_merge_effort"] = idle_arrangement_merge_effort
        __props__.__dict__["introspection_debugging"] = introspection_debugging
        __props__.__dict__["introspection_interval"] = introspection_interval
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["region"] = region
        __props__.__dict__["replication_factor"] = replication_factor
        __props__.__dict__["size"] = size
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def disk(self) -> pulumi.Output[Optional[bool]]:
        """
        **Private Preview**. Whether or not the replica is a *disk-backed replica*.
        """
        return pulumi.get(self, "disk")

    @property
    @pulumi.getter(name="idleArrangementMergeEffort")
    def idle_arrangement_merge_effort(self) -> pulumi.Output[Optional[int]]:
        """
        The amount of effort to exert compacting arrangements during idle periods. This is an unstable option! It may be changed or removed at any time.
        """
        return pulumi.get(self, "idle_arrangement_merge_effort")

    @property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> pulumi.Output[Optional[str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> pulumi.Output[int]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[Optional[str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

